﻿using System.Drawing;
using System.Windows.Forms;

using Lassalle.Flow;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            CreateDiagram(this.addFlow);
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 다이어그램 생성하기 - CreateDiagram(addFlow)

        /// <summary>
        /// 다이어그램 생성하기
        /// </summary>
        /// <param name="addFlow">AddFlow</param>
        private void CreateDiagram(AddFlow addFlow)
        {
            // 노드들을 위한 디폴트 속성 값들을 설정한다.
            addFlow.NodeModel.FillColor   = Color.LightYellow;
            addFlow.NodeModel.ShadowStyle = ShadowStyle.RightBottom;

            // 링크들을 위한 디폴트 속성 값들을 설정한다.
            addFlow.LinkModel.DrawColor = Color.Blue;
            addFlow.LinkModel.BackMode  = BackMode.Opaque;

            // 캡션들을 위한 디폴트 속성 값들을 설정한다.
            addFlow.CaptionModel.TextColor = Color.Blue;
            addFlow.CaptionModel.DrawColor = Color.Transparent;
            addFlow.CaptionModel.Font      = new Font("Calibri", 14);

            // 그림자를 갖는 3개의 노랑색 노드들을 생성한다.
            // 두번째 노드는 사각형이고
            // 세번째 노드는 Document 도형 스타일이다.
            Node node1 = new Node(50 , 50 , 80 , 80, "첫번째 노드", addFlow);
            Node node2 = new Node(280, 160, 100, 80, "두번째 노드", addFlow);
            Node node3 = new Node(50 , 210, 80 , 80, "세번쨰 노드", addFlow);

            node2.ShapeFamily = ShapeFamily.Rectangle;

            node3.ShapeFamily  = ShapeFamily.Rectangle;
            node3.GraphicsPath = PredefinedGeometry.GetNodePath(NodeShapeStyle.Document, ShapeOrientation.Degree0);

            // 3개의 링크를 생성한다.
            // 각 링크는 파랑색이고 BackMode 속성은 Opaque로 설정한다.
            // 두번째 링크는 베지어 스타일을 갖고, 텍스트 색상은 빨강색이고, 목적지 화살표 각도는 30도 이다.
            // 세번째 링크는 HVH 스타일을 갖는다.
            Link link1 = new Link(node1, node2, "링크 1", addFlow);
            Link link2 = new Link(node2, node2, "링크 2", addFlow);
            Link link3 = new Link(node2, node3, "링크 3", addFlow);

            link2.LineStyle = LineStyle.Bezier;
            link2.TextColor = Color.Red;
            link2.ArrowDst  = PredefinedGeometry.GetLinkArrowStylePath(LinkArrowStyle.Arrow, 10, 14);

            link3.LineStyle = LineStyle.Orthogonal;

            // 1개의 캡션을 생성한다.
            Caption caption = new Caption(200, 30, 220, 30, "디폴트 속성들", null, addFlow);

            // 다이어그램에 항목들을 추가한다.
            addFlow.AddNode(node1);
            addFlow.AddNode(node2);
            addFlow.AddNode(node3);

            addFlow.AddLink(link1);
            addFlow.AddLink(link2);
            addFlow.AddLink(link3);

            addFlow.AddCaption(caption); 
        }

        #endregion
    }
}